@@ -36,14 +36,14 @@ The frames are used as a container for other widgets.
 import tkinter as tk
 from tkinter import ttk  # allow using Tk themed widget set
 
-__author__ = '''Vincent Schouten <inquiry@intoreflection.co>'''
+__author__ = '''Vincent Schouten <powermole@protonmail.com>'''
 __docformat__ = '''google'''
 __date__ = '''06-12-2019'''
 __copyright__ = '''Copyright 2021, Vincent Schouten'''
 __credits__ = ["Vincent Schouten"]
 __license__ = '''MIT'''
 __maintainer__ = '''Vincent Schouten'''
-__email__ = '''<inquiry@intoreflection.co>'''
+__email__ = '''<powermole@protonmail.com>'''
 __status__ = '''Development'''  # "Prototype", "Development", "Production".
 
 # Constants
